module_suffix=$(echo $1 | sed "s/^babel-//")
for i in ${module_suffix}
# Strip babel- if added by mistake
do
  cp node-babel-types.install node-babel-${module_suffix}.install
  cp node-babel-types.docs node-babel-${module_suffix}.docs
  sed -i s/types/${module_suffix}/g node-babel-${module_suffix}.*
done
