#!/bin/sh

cat > debian/node-babel-preset-es2015.install <<EOF
packages/babel-preset-es2015/package.json usr/lib/nodejs/babel-preset-es2015
packages/babel-preset-es2015/lib usr/lib/nodejs/babel-preset-es2015
EOF

cd packages
for i in babel-plugin-*-es2015-*
do
	echo "packages/$i/package.json usr/lib/nodejs/$i" >> ../debian/node-babel-preset-es2015.install
	echo "packages/$i/lib usr/lib/nodejs/$i" >> ../debian/node-babel-preset-es2015.install
done
